@@ -517,6 +517,9 @@ class google_routesearch:
             return m[2]
 
     def do_draw(self, gpsmap, gdkdrawable):
+        if notself.drive_mode:
+            return 0
+        
         print "drive mode", self.drive_mode
 
         if self.osmMapa.osm.props.zoom>self.zoom_minimum:
